aboutsummaryrefslogtreecommitdiffhomepage
diff options
context:
space:
mode:
-rw-r--r--site/_layouts/contribute.html4
-rw-r--r--site/_layouts/documentation.html4
-rw-r--r--site/_sass/style.scss32
-rw-r--r--site/blog/_posts/2016-01-27-continuous-integration.md55
-rw-r--r--site/blog/_posts/2016-06-10-ide-support.md10
-rw-r--r--site/docs/bazel-user-manual.html9
-rw-r--r--site/docs/query-how-to.html2
-rw-r--r--site/docs/skyframe.md2
-rw-r--r--site/docs/skylark/deploying.md2
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/java/JavaCompileAction.java2
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/java/JavaConfiguration.java10
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/java/JavaConfigurationLoader.java4
-rw-r--r--src/main/java/com/google/devtools/build/lib/rules/java/JavaOptions.java23
13 files changed, 106 insertions, 53 deletions
diff --git a/site/_layouts/contribute.html b/site/_layouts/contribute.html
index 1cb71fa724..98a11aedb0 100644
--- a/site/_layouts/contribute.html
+++ b/site/_layouts/contribute.html
@@ -16,7 +16,7 @@ nav: contribute
<div class="container vpad">
<div class="row">
- <div class="col-lg-2 col-md-3">
+ <div class="col-lg-3">
<a class="btn btn-default btn-lg btn-block sidebar-toggle"
data-toggle="collapse" href="#sidebar-nav" aria-expanded="false"
aria-controls="sidebar-nav">
@@ -44,7 +44,7 @@ nav: contribute
</ul>
</nav>
</div>
- <div class="col-lg-10 col-md-9">
+ <div class="col-lg-9">
{{ content }}
</div>
</div>
diff --git a/site/_layouts/documentation.html b/site/_layouts/documentation.html
index 6616fded7d..576ecc08ee 100644
--- a/site/_layouts/documentation.html
+++ b/site/_layouts/documentation.html
@@ -16,7 +16,7 @@ nav: docs
<div class="container vpad">
<div class="row">
- <div class="col-lg-2 col-md-3">
+ <div class="col-lg-3">
<a class="btn btn-default btn-lg btn-block sidebar-toggle"
data-toggle="collapse" href="#sidebar-nav" aria-expanded="false"
aria-controls="sidebar-nav">
@@ -89,7 +89,7 @@ nav: docs
</ul>
</nav>
</div>
- <div class="col-lg-10 col-md-9">
+ <div class="col-lg-9">
{{ content }}
</div>
</div>
diff --git a/site/_sass/style.scss b/site/_sass/style.scss
index b999cc0cd1..b1ebf95fe7 100644
--- a/site/_sass/style.scss
+++ b/site/_sass/style.scss
@@ -71,6 +71,10 @@ a {
&:focus {
color: $link-hover-color;
}
+
+ code {
+ color: $link-color;
+ }
}
h1,
@@ -81,10 +85,20 @@ h5,
h6 {
color: $text-color;
font-weight: 300;
- margin-top: 25px;
+ margin-top: 30px;
margin-bottom: 15px;
}
+h1 code,
+h2 code,
+h3 code,
+h4 code,
+h5 code,
+h6 code {
+ color: $text-color;
+ background: transparent;
+}
+
h1 {
margin-top: 40px;
}
@@ -92,14 +106,26 @@ h1 {
h2 {
font-size: 24px;
margin-top: 30px;
+
+ code {
+ font-size: 24px;
+ }
}
h3 {
- font-size: 18px;
+ font-size: 20px;
+
+ code {
+ font-size: 20px;
+ }
}
h4 {
- font-size: 16px;
+ font-size: 18px;
+
+ code {
+ font-size: 18px;
+ }
}
p,
diff --git a/site/blog/_posts/2016-01-27-continuous-integration.md b/site/blog/_posts/2016-01-27-continuous-integration.md
index 7158bfcace..130e0d5a41 100644
--- a/site/blog/_posts/2016-01-27-continuous-integration.md
+++ b/site/blog/_posts/2016-01-27-continuous-integration.md
@@ -92,23 +92,56 @@ A final consideration when setting up a continuous integration system is getting
the result from the build. Bazel has the following interesting exit codes when
using `test` and `build` commands:
-- 0 - Success.
-- 1 - Build failed.
-- 2 - Command Line Problem, Bad or Illegal flags or command combination, or
- Bad Environment Variables. Your command line must be modified.
-- 2 - Command line error.
-- 3 - Build OK, but some tests failed or timed out.
-- 4 - Build successful but no tests were found even though testing was
- requested.
-- 8 - Build interrupted (by a Ctrl+C from the user for instance) but we
- terminated with an orderly shutdown.
+<table class="table table-condensed table-striped">
+ <thead>
+ <tr>
+ <th>Exit Code</th>
+ <th>Description</th>
+ </tr>
+ </thead>
+ <tbody>
+ <tr>
+ <td>0</td>
+ <td>Success.</td>
+ </tr>
+ <tr>
+ <td>1</td>
+ <td>Build failed.</td>
+ </tr>
+ <tr>
+ <td>2</td>
+ <td>
+ Command Line Problem, Bad or Illegal flags or command combination, or
+ Bad Environment Variables. Your command line must be modified.
+ </td>
+ </tr>
+ <tr>
+ <td>3</td>
+ <td>Build OK, but some tests failed or timed out.</td>
+ </tr>
+ <tr>
+ <td>4</td>
+ <td>
+ Build successful but no tests were found even though testing was
+ requested.
+ </td>
+ </tr>
+ <tr>
+ <td>8</td>
+ <td>
+ Build interrupted (by a <kbd><kbd>Ctrl</kbd>+<kbd>C</kbd></kbd> from the
+ user for instance) but we terminated with an orderly shutdown.
+ </td>
+ </tr>
+ </tbody>
+</table>
These return codes can be used to determine the reason for a failure
(in [ci.bazel.io](http://ci.bazel.io), we mark builds that have exited with exit
code 3 as unstable, and other non zero code as failed).
You can also control how much information about test results Bazel prints out
-with the [--test_output flag](http://bazel.io/docs/bazel-user-manual.html#flag--test_output).
+with the [`--test_output` flag](http://bazel.io/docs/bazel-user-manual.html#flag--test_output).
Generally, printing the output of test that fails with `--test_output=errors` is
a good setting for a CI system.
diff --git a/site/blog/_posts/2016-06-10-ide-support.md b/site/blog/_posts/2016-06-10-ide-support.md
index dbe8e729b4..11dadc27d2 100644
--- a/site/blog/_posts/2016-06-10-ide-support.md
+++ b/site/blog/_posts/2016-06-10-ide-support.md
@@ -48,13 +48,13 @@ a look at a sample
[Eclipse plugin for Bazel support, e4b](https://github.com/bazelbuild/e4b).
e4b includes an aspect, defined in a file
-[e4b_aspect.bzl](https://github.com/bazelbuild/e4b/blob/master/com.google.devtools.bazel.e4b/resources/tools/must/be/unique/e4b_aspect.bzl),
+[`e4b_aspect.bzl`](https://github.com/bazelbuild/e4b/blob/master/com.google.devtools.bazel.e4b/resources/tools/must/be/unique/e4b_aspect.bzl),
that when
applied to a particular target, generates a small JSON file with information
about that target relevant to Eclipse. Those JSON files are then consumed
by the e4b plugin inside Eclipse to build [Eclipse's representation
of a project](https://github.com/bazelbuild/e4b/blob/master/com.google.devtools.bazel.e4b/src/com/google/devtools/bazel/e4b/classpath/BazelClasspathContainer.java),
-[IClasspathContainer](http://help.eclipse.org/juno/index.jsp?topic=%2Forg.eclipse.jdt.doc.isv%2Freference%2Fapi%2Forg%2Feclipse%2Fjdt%2Fcore%2FIClasspathContainer.html):
+[`IClasspathContainer`](http://help.eclipse.org/juno/index.jsp?topic=%2Forg.eclipse.jdt.doc.isv%2Freference%2Fapi%2Forg%2Feclipse%2Fjdt%2Fcore%2FIClasspathContainer.html):
![e4bazel workflow](/assets/e4b-workflow.png)
@@ -72,8 +72,8 @@ bazel build //java/com/company/example:main \
[e4b source](https://github.com/bazelbuild/e4b/blob/master/com.google.devtools.bazel.e4b/src/com/google/devtools/bazel/e4b/command/BazelCommand.java) for complete
invocation)
-The "--aspects" flag directs Bazel to apply e4b_aspect, exported from
-e4bazel.bzl Skylark extension, to target //java/com/company/example:main.
+The `--aspects` flag directs Bazel to apply `e4b_aspect`, exported from
+`e4bazel.bzl` Skylark extension, to target `//java/com/company/example:main`.
The aspect is then applied transitively to the dependencies of the specified
targets, producing `.e4b-build.json` files for each target in the transitive
@@ -88,7 +88,7 @@ group (and hence only to the aspect) are built, and therefore that no
unnecessary build steps are performed.
The aspect uses the
-['java' provider](/docs/skylark/lib/JavaSkylarkApiProvider.html) on the targets
+[`java` provider](/docs/skylark/lib/JavaSkylarkApiProvider.html) on the targets
it applies to to access a variety of information about Java targets.
diff --git a/site/docs/bazel-user-manual.html b/site/docs/bazel-user-manual.html
index 66b4a1229b..efdf1d1426 100644
--- a/site/docs/bazel-user-manual.html
+++ b/site/docs/bazel-user-manual.html
@@ -2250,7 +2250,7 @@ either to the terminal, or to additional log files.
which drive a build.
</p>
-<h4 id='flag--subcommands'><code class='flag'>--subcommands</code> (-s)</h4>
+<h4 id='flag--subcommands'><code class='flag'>--subcommands</code> (<code>-s</code>)</h4>
<p>
This option causes Bazel's execution phase to print the full command line
for each command prior to executing it.
@@ -2419,7 +2419,7 @@ either to the terminal, or to additional log files.
<h3>Options for <code>bazel test</code></h3>
-<h4 id="flag--cache_test_results"><code class='flag'>--cache_test_results=(yes|no|auto)</code> (-t)</h4>
+<h4 id="flag--cache_test_results"><code class='flag'>--cache_test_results=(yes|no|auto)</code> (<code>-t</code>)</h4>
<p>
If this option is set to 'auto' (the default) then Bazel will only rerun a test if any of the
following conditions applies:
@@ -2854,7 +2854,7 @@ in an environment closer to the current shell environment. Note that none of the
that do not correspond to commands.
</p>
-<h4 id='flag--long'><code class='flag'>--[no]long</code> (-l)</h4>
+<h4 id='flag--long'><code class='flag'>--[no]long</code> (<code>-l</code>)</h4>
<p>
By default, <code>bazel help [<var>topic</var>]</code> prints only a
summary of the relevant options for a topic. If
@@ -2928,8 +2928,7 @@ in an environment closer to the current shell environment. Note that none of the
symlink named
<code>bazel-&lt;workspace&gt;</code>
- is placed there pointing to this
- directory.
+ is placed there pointing to this directory.
</li>
<li><code>output_path</code>: the absolute path to the output
directory beneath the execution root used for all files actually
diff --git a/site/docs/query-how-to.html b/site/docs/query-how-to.html
index 37d1b88055..8920843812 100644
--- a/site/docs/query-how-to.html
+++ b/site/docs/query-how-to.html
@@ -177,8 +177,6 @@ $ <kbd>bazel query "allpaths(src/main/java/com/example/common/base:base, third_p
//third_party/openssl:crypto
</pre>
<p />
-</div>
-<p />
<h3><a name="Aside_implicit_dependencies"> </a> Aside: implicit dependencies </h3>
<div>
<p />
diff --git a/site/docs/skyframe.md b/site/docs/skyframe.md
index de2a0b725e..ae3dc53aee 100644
--- a/site/docs/skyframe.md
+++ b/site/docs/skyframe.md
@@ -1,5 +1,5 @@
---
-layout: documentation
+layout: contribute
title: Skyframe
---
diff --git a/site/docs/skylark/deploying.md b/site/docs/skylark/deploying.md
index f648ad44ac..ad0831ccff 100644
--- a/site/docs/skylark/deploying.md
+++ b/site/docs/skylark/deploying.md
@@ -2,8 +2,6 @@
layout: documentation
title: Deploying new Skylark rules
---
--->
-
# Deploying new Skylark rules
This documentation is for Skylark rule writers who are planning to make their
diff --git a/src/main/java/com/google/devtools/build/lib/rules/java/JavaCompileAction.java b/src/main/java/com/google/devtools/build/lib/rules/java/JavaCompileAction.java
index d5651aee2f..2508d1d810 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/java/JavaCompileAction.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/java/JavaCompileAction.java
@@ -873,7 +873,7 @@ public final class JavaCompileAction extends AbstractAction {
compileTimeDependencyArtifacts.clear();
}
- // Invariant: if experimental_java_classpath is not set to 'javabuilder',
+ // Invariant: if java_classpath is not set to 'javabuilder',
// dependencyArtifacts are ignored
if (javaConfiguration.getReduceJavaClasspath() != JavaClasspathMode.JAVABUILDER) {
compileTimeDependencyArtifacts.clear();
diff --git a/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfiguration.java b/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfiguration.java
index ab9cde87d3..f7ccb344c0 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfiguration.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfiguration.java
@@ -43,9 +43,7 @@ import javax.annotation.Nullable;
category = SkylarkModuleCategory.CONFIGURATION_FRAGMENT
)
public final class JavaConfiguration extends Fragment {
- /**
- * Values for the --experimental_java_classpath option
- */
+ /** Values for the --java_classpath option */
public static enum JavaClasspathMode {
/** Use full transitive classpaths, the default behavior. */
OFF,
@@ -133,7 +131,7 @@ public final class JavaConfiguration extends Fragment {
private final boolean useHeaderCompilation;
private final boolean optimizeHeaderCompilationAnnotationProcessing;
private final boolean generateJavaDeps;
- private final JavaClasspathMode experimentalJavaClasspath;
+ private final JavaClasspathMode javaClasspath;
private final ImmutableList<String> javaWarns;
private final ImmutableList<String> defaultJvmFlags;
private final ImmutableList<String> checkedConstraints;
@@ -161,7 +159,7 @@ public final class JavaConfiguration extends Fragment {
this.optimizeHeaderCompilationAnnotationProcessing =
javaOptions.optimizeHeaderCompilationAnnotationProcessing;
this.generateJavaDeps = generateJavaDeps;
- this.experimentalJavaClasspath = javaOptions.experimentalJavaClasspath;
+ this.javaClasspath = javaOptions.javaClasspath;
this.javaWarns = ImmutableList.copyOf(javaOptions.javaWarns);
this.defaultJvmFlags = ImmutableList.copyOf(defaultJvmFlags);
this.checkedConstraints = ImmutableList.copyOf(javaOptions.checkedConstraints);
@@ -235,7 +233,7 @@ public final class JavaConfiguration extends Fragment {
}
public JavaClasspathMode getReduceJavaClasspath() {
- return experimentalJavaClasspath;
+ return javaClasspath;
}
/**
diff --git a/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfigurationLoader.java b/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfigurationLoader.java
index b82a1b15cd..c6eda487fb 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfigurationLoader.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/java/JavaConfigurationLoader.java
@@ -62,8 +62,8 @@ public class JavaConfigurationLoader implements ConfigurationFragmentFactory {
public JavaConfiguration create(JavaOptions javaOptions, Label javaToolchain, String javaCpu)
throws InvalidConfigurationException {
- boolean generateJavaDeps = javaOptions.javaDeps ||
- javaOptions.experimentalJavaClasspath != JavaClasspathMode.OFF;
+ boolean generateJavaDeps =
+ javaOptions.javaDeps || javaOptions.javaClasspath != JavaClasspathMode.OFF;
return new JavaConfiguration(
generateJavaDeps, javaOptions.jvmOpts, javaOptions, javaToolchain, javaCpu);
diff --git a/src/main/java/com/google/devtools/build/lib/rules/java/JavaOptions.java b/src/main/java/com/google/devtools/build/lib/rules/java/JavaOptions.java
index 7a96eae467..025c1e0820 100644
--- a/src/main/java/com/google/devtools/build/lib/rules/java/JavaOptions.java
+++ b/src/main/java/com/google/devtools/build/lib/rules/java/JavaOptions.java
@@ -79,9 +79,7 @@ public class JavaOptions extends FragmentOptions {
}
}
/**
* Converter for the --experimental_java_classpath option.
*/
public static class JavaClasspathModeConverter extends EnumConverter<JavaClasspathMode> {
public JavaClasspathModeConverter() {
super(JavaClasspathMode.class, "Java classpath reduction strategy");
@@ -189,13 +187,16 @@ public class JavaOptions extends FragmentOptions {
help = "Generate dependency information (for now, compile-time classpath) per Java target.")
public boolean javaDeps;
- @Option(name = "experimental_java_classpath",
- allowMultiple = false,
- defaultValue = "javabuilder",
- converter = JavaClasspathModeConverter.class,
- category = "semantics",
- help = "Enables reduced classpaths for Java compilations.")
- public JavaClasspathMode experimentalJavaClasspath;
+ @Option(
+ name = "java_classpath",
+ allowMultiple = false,
+ defaultValue = "javabuilder",
+ converter = JavaClasspathModeConverter.class,
+ category = "semantics",
+ help = "Enables reduced classpaths for Java compilations.",
+ oldName = "experimental_java_classpath"
+ )
+ public JavaClasspathMode javaClasspath;
@Option(name = "java_debug",
defaultValue = "null",
@@ -364,7 +365,7 @@ public class JavaOptions extends FragmentOptions {
host.useIjars = useIjars;
host.javaDeps = javaDeps;
- host.experimentalJavaClasspath = experimentalJavaClasspath;
+ host.javaClasspath = javaClasspath;
return host;
}
@@ -79,9 +79,7 @@ public class JavaOptions extends FragmentOptions {
}
}
- /**
- * Converter for the --experimental_java_classpath option.
- */
+ /** Converter for the --java_classpath option. */
public static class JavaClasspathModeConverter extends EnumConverter<JavaClasspathMode> {
public JavaClasspathModeConverter() {